var simple_module = function(transactions, input) {
	
	// HTML and CSS for this file
	var html = `
<div id="quickoverall" class="row">
	<div class="six columns">
		<h4>Quick Information</h4>
		<ul>
			<li>File <span id="info_file_name">FILENAME</span> was loaded.</li>
			<li><span id="info_transaction_count">COUNT</span> transaction(s) found within selected timespan.</li>
			<li>First transaction happened on <span id="info_first">-</span>.</li>
			<li>Last transaction happened on <span id="info_last">-</span>.</li>
		</ul>
	</div>
	<div class="six columns">
		<h4>Overall Statistics</h4>
		<ul>
			<li><span id="simple_count_pos">COUNT</span> positive transaction(s).</li>
			<li>Total positive money flow <span id="simple_flow_pos">AMOUNT</span>.</li>
			<li><span id="simple_count_neg">COUNT</span> negative transaction(s).</li>
			<li>Total negative money flow <span id="simple_flow_neg">AMOUNT</span>.</li>
		</ul>
	</div>
</div>
<div id="statisticstable" class="row">
	<div class="column">
		<h4>Table of Statistics per Time Frame</h4>
		<table>
			<thead></thead>
			<tbody></tbody>
		</table>
	</div>
</div>
	`;
	jQuery("#modules").append(html);

	console.log(input);
	
	// Get simple statistics of a transactionSet
	var getStatistics = function(transactionSet) {
		var transactions_pos = transactionSet.filter(function (t) { return t.amount >= 0; });
		var transactions_neg = transactionSet.filter(function (t) { return t.amount <  0; });
		return {
			positiveCount: transactions_pos.length,
			positiveSum: input.currency + " " + (+d3.sum(transactions_pos, function (a) { return a.amount; })).toFixed(2),
			negativeCount: transactions_neg.length,
			negativeSum: input.currency + " " + (-d3.sum(transactions_neg, function (a) { return a.amount; })).toFixed(2),
		};
	};
		
	// Set data and show 'Quick Information and Overall Statistics'
	var quickoverall = function() {
		// Quick Information
		jQuery("#info_file_name").html(input.file.name);
		jQuery("#info_transaction_count").html(transactions.length);
		if (transactions.length > 0) {
			jQuery("#info_first").html(_.first(transactions).date.toDateString());
			jQuery("#info_last").html(_.last(transactions).date.toDateString());
		}
		
		// Simple Statistics
		var statistics = getStatistics(transactions);
		jQuery("#simple_count_pos").html(statistics.positiveCount);
		jQuery("#simple_count_neg").html(statistics.negativeCount);
		jQuery("#simple_flow_pos").html(statistics.positiveSum);
		jQuery("#simple_flow_neg").html(statistics.negativeSum);
		
		// Show the whole section
		jQuery("#quickoverall").show();
	};
	
	// Set data and show 'Statistics Table per Time Frame'
	var statisticstable = function() {
		// Gather data
		var statisticsTableRows = d3.nest()
			.key(function (transaction) { var k = transaction.getKeyValue(input.timeframe); return "<span hidden>" + k.name + "</span>" + k.label; })
			.rollup(getStatistics)
			.entries(transactions);
		
		// Remove already existing data
		jQuery("#statisticstable th").remove();
		jQuery("#statisticstable tr").remove();
		
		// Generate columns
		var columnNames = _.keys(getStatistics([]));
		var columnRow = jQuery("<tr></tr>");
		columnRow.append("<th>_</th>");
		columnNames.forEach(function(column) {
			var columnFull = "<th>" + column.replace(/([A-Z])/g, ' $1').replace(/^./, function(str){ return str.toUpperCase(); }) + "</th>";
			columnRow.append(columnFull);
		});
		jQuery("#statisticstable thead").append(columnRow);
		
		// Generate rows for each data key
		statisticsTableRows.forEach(function (rowData) {
			var row = jQuery("<tr></tr>");
			row.append("<td>" + rowData.key  + "</td>");
			columnNames.forEach(function (columnName) {
				row.append("<td>" + rowData.value[columnName] + "</td>");
			});
			jQuery("#statisticstable tbody").append(row);
		});
		
		// Make the table a jQuery.DataTable to allow sorting
		jQuery("#statisticstable table").DataTable({
			paging: false,
			searching: false,
			info: false,
		});
		
		// Show the whole section
		jQuery("#statisticstable").show();
	};
		
	// Execute submodules
	quickoverall();
	statisticstable();
	
};